@@ -1,5 +1,6 @@
 import time
 from typing import Callable
+
 from fastapi import Request
 from starlette.middleware.base import BaseHTTPMiddleware
 
@@ -7,6 +8,7 @@ from nlbone.config.logging import get_logger
 
 logger = get_logger(__name__)
 
+
 class AccessLogMiddleware(BaseHTTPMiddleware):
     async def dispatch(self, request: Request, call_next: Callable):
         start = time.perf_counter()
@@ -20,11 +22,13 @@ class AccessLogMiddleware(BaseHTTPMiddleware):
             raise
         finally:
             dur_ms = int((time.perf_counter() - start) * 1000)
-            logger.info({
-                "event": "access",
-                "method": request.method,
-                "path": request.url.path,
-                "status": status_code,
-                "duration_ms": dur_ms,
-                "query": request.url.query,
-            })
+            logger.info(
+                {
+                    "event": "access",
+                    "method": request.method,
+                    "path": request.url.path,
+                    "status": status_code,
+                    "duration_ms": dur_ms,
+                    "query": request.url.query,
+                }
+            )
