@@ -3,6 +3,7 @@ from typing import Callable, Optional, Union
 from fastapi import Request
 from starlette.middleware.base import BaseHTTPMiddleware
 
+from nlbone.config.settings import get_settings
 from nlbone.adapters.auth.auth_service import AuthService
 
 try:
@@ -50,7 +51,9 @@ def authenticate_admin_user(request, auth_service):
             pass
 
 def authenticate_user(request):
-    token = request.cookies.get("access_token") or request.cookies.get("j_token")
+    token = request.cookies.get("access_token") or request.cookies.get("j_token") or request.headers.get("Authorization")
+    if request.headers.get("Authorization"):
+        scheme, token = request.headers.get("Authorization").split(" ", 1)
 
     if token:
         request.state.token = token
@@ -69,10 +72,16 @@ class AuthenticationMiddleware(BaseHTTPMiddleware):
         self._get_auth = _to_factory(auth)
 
     async def dispatch(self, request: Request, call_next):
-        request.state.client_id = request.headers.get("X-Client-Id")
+        request.state.client_id = None
         request.state.user_id = None
         request.state.token = None
-        if request.cookies.get("access_token"):
+        if request.headers.get('X-Client-Id') and request.headers.get("X-Api_Key"):
+            if request.headers.get("X-Api_Key") == get_settings().PRICING_API_SECRET:
+                request.state.client_id = request.headers.get("X-Client-Id")
+                return await call_next(request)
+        if request.headers.get('X-Client-Id') == 'website' and request.headers.get("Authorization"):
+            authenticate_user(request)
+        elif request.cookies.get("access_token"):
             authenticate_user(request)
         elif request.headers.get("Authorization"):
             authenticate_admin_user(request, auth_service=self._get_auth)
